@@ -266,16 +266,15 @@ class RequestQueuer(object):
             LOGGER.critical("CHECK ACTIVE LOOP")   
             hosts = self.pending_reqs.keys()
             for host in hosts:
-                if self._hostRequestCheck(host):
-                    if len(self.pending_reqs[host]) == 0:
-                        del self.pending_reqs[host]
-                    else:
-                        req = self.pending_reqs[host].pop(0)
-                        d = self._getPage(req)
-                        d.addCallback(self._requestComplete, req["deferred"], host)
-                        d.addErrback(self._requestError, req["deferred"], host)
-                        self.last_req[host] = time.time()
-                        self.active_reqs[host] = self.active_reqs.get(host, 0) + 1
+                if len(self.pending_reqs[host]) == 0:
+                    del self.pending_reqs[host]
+                elif self._hostRequestCheck(host):
+                    req = self.pending_reqs[host].pop(0)
+                    d = self._getPage(req)
+                    d.addCallback(self._requestComplete, req["deferred"], host)
+                    d.addErrback(self._requestError, req["deferred"], host)
+                    self.last_req[host] = time.time()
+                    self.active_reqs[host] = self.active_reqs.get(host, 0) + 1
 
     def _requestComplete(self, response, deferred, host):
         self.active_reqs[host] -= 1
